%global upstreamver 4r7
%global majorver %(cut -dp -f1 <<< %{upstreamver})
%global pkgname grape

Name:           gap-pkg-%{pkgname}
Version:        %(sed -r "s/r|p/./g" <<< %{upstreamver})
Release:        1%{?dist}
Summary:        GRaph Algorithms using PErmutation groups

License:        GPLv2+
URL:            http://www.maths.qmul.ac.uk/~leonard/%{pkgname}/
Source0:        http://www.maths.qmul.ac.uk/~leonard/%{pkgname}/%{pkgname}%{majorver}/%{pkgname}%{upstreamver}.tar.gz
BuildArch:      noarch

BuildRequires:  bliss
BuildRequires:  gap-devel
BuildRequires:  tex-tex
BuildRequires:  tth

Requires:       bliss
Requires:       gap-core

%description
GRAPE is a package for computing with graphs and groups, and is
primarily designed for constructing and analyzing graphs related to
groups, finite geometries, and designs.

The upstream GRAPE package uses calls to nauty for some functions.
Since nauty is excluded from Fedora for license reasons, the Fedora
version of GRAPE uses bliss instead.

%prep
%setup -q -n %{pkgname}

# Remove nauty so we don't accidentally use it (license problems)
rm -fr bin/* nauty22

fixtimestamp() {
  touch -r $1.orig $1
  rm -f $1.orig
}

# Fix encoding
iconv -f iso8859-1 -t utf-8 PackageInfo.g > PackageInfo.g.utf8
touch -r PackageInfo.g PackageInfo.g.utf8
mv -f PackageInfo.g.utf8 PackageInfo.g

# Fix broken references to the GAP manual
sed -i.orig 's/Reference:/ref:/g' doc/grape.tex
fixtimestamp doc/grape.tex

# Use bliss, and fix the path to the bliss executable
sed -e '/GRAPE_NAUTY/s/true; /false;/' \
    -e 's,\(GRAPE_BLISS_EXE := \).*,\1"%{_bindir}/bliss";,' \
    -i.orig lib/grape.g
fixtimestamp lib/grape.g

%build
# Link to main GAP documentation
ln -s %{_gap_dir}/etc ../../etc
ln -s %{_gap_dir}/doc ../../doc
pushd doc
./make_doc
popd
rm -f ../../{doc,etc}

%install
mkdir -p %{buildroot}%{_gap_dir}/pkg
cp -a ../%{pkgname} %{buildroot}%{_gap_dir}/pkg
rm -f %{buildroot}%{_gap_dir}/pkg/%{pkgname}/{doc/make_doc,COPYING,gpl.txt,README}
rm -f %{buildroot}%{_gap_dir}/pkg/%{pkgname}/doc/*.{aux,bbl,blg,idx,ilg,ind,log,toc}

%check
gap -l "%{buildroot}%{_gap_dir};%{_gap_dir}" << EOF 2>&1 | tee log
ReadTest( "tst/testall.tst" );
EOF
if grep -Fq Error log; then false; else true; fi
rm -f log

%files
%doc README
%license COPYING gpl.txt
%docdir %{_gap_dir}/pkg/%{pkgname}/doc
%{_gap_dir}/pkg/%{pkgname}/

%changelog
* Wed Jan 20 2016 Jerry James <loganjerry@gmail.com> - 4.7-1
- New upstream version
- Drop upstreamed bliss patch

* Wed Nov 11 2015 Jerry James <loganjerry@gmail.com> - 4.6.1-2
- Drop scriptlets; gap-core now uses rpm file triggers
- Rebuild documentation from source
- Turn test failures into build failures
- New version of bliss patch from upstream

* Mon Oct 19 2015 Jerry James <loganjerry@gmail.com> - 4.6.1-1
- Initial RPM
